<html>
    <head>
        <title>Страница оплаты</title>
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">

        <style type="text/css">
            ul {
                list-style: none;
            }
            input {
                min-width: 250px;
            }
        </style>
    </head>
    <body>
        <form action="https://paymecash.me/api/payment" method="POST" id="id_payform">
            <ul>
                <div id="id_payform_fields">
                    {{ form.as_ul|safe }}
                </div>
                <li>
                    <input type="submit" />
                </li>
            </ul>
        </form>
    </body>
</html>